@@ -662,7 +662,7 @@ def execute_strategy_multi_asset(
                             ) / float_price,
                             dict_general_settings['int_rounding_decimal_places_for_security_quantities']
                         )
-                        print('BUY CORRECT')
+                        print('BUY CORRECT', float_number_to_be_bought)
                     else:
                         float_number_to_be_bought = round(
                             (
@@ -675,9 +675,6 @@ def execute_strategy_multi_asset(
                 else:
                     float_number_to_be_bought = None
 
-                if float_number_to_be_bought is not None:
-                    float_number_to_be_bought = float_number_to_be_bought * dict_strategy_hyperparameters['float_maximum_relative_exposure_per_buy']
-
             elif row['signal_type'] == "SELL":
                 boolean_buy = False
                 # Check if exposure for this asset is zero and skip dict_order if so
@@ -700,7 +697,7 @@ def execute_strategy_multi_asset(
                             ) / float_price,
                             dict_general_settings['int_rounding_decimal_places_for_security_quantities']
                         )
-                        print('SELL CORRECT')
+                        print('SELL CORRECT', float_number_to_be_bought)
                     else:
                         float_number_to_be_bought = (-1) * (
                             find_dataframe_value_with_keywords(
